===============================
CosmicPi Web
===============================


.. image:: https://img.shields.io/pypi/v/cosmicpi_web.svg
        :target: https://pypi.python.org/pypi/cosmicpi_web

.. image:: https://img.shields.io/travis/CosmicPi/cosmicpi-web.svg
        :target: https://travis-ci.org/CosmicPi/cosmicpi-web

Web frontend for Cosmic Pi


* Free software: GNU General Public License v3
* Documentation: https://cosmicpi-web.readthedocs.io.


Features
--------

* Provides a frontend web application for displaying cosmic events.
